#!perl
#
#
package  Test::TestUtil::Drivers::IO;

use strict;
use warnings;
use warnings::register;

use vars qw($VERSION $DATE $FILE );
$VERSION = '0.01';
$DATE = '2003/06/12';
$FILE = __FILE__;

__END_
